@@ -22,7 +22,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <glib.h>
 #include <glib/gprintf.h>
@@ -38,7 +38,7 @@
 #include "gdk-pixbuf/gdk-pixbuf-private.h"
 #include "gdk-pixbuf/gdk-pixbuf-io.h"
 
-#if USE_LA_MODULES
+#ifdef USE_LA_MODULES
 #define SOEXT ".la"
 #else
 #define SOEXT ("." G_MODULE_SUFFIX)
@@ -81,7 +81,7 @@ loader_sanity_check (const char *path, GdkPixbufFormat *info, GdkPixbufModule *v
 				
 				goto error;
 			}
-			if (strspn (pattern->mask, " !xzn") < mask_len) 
+			if (strspn (pattern->mask, " !xzn*") < mask_len) 
 			{
 				error = "bad char in mask";
 				
@@ -104,7 +104,7 @@ loader_sanity_check (const char *path, GdkPixbufFormat *info, GdkPixbufModule *v
 		goto error;
 	}
 
-	if ((info->flags & GDK_PIXBUF_FORMAT_WRITABLE) && !vtable->save) 
+	if ((info->flags & GDK_PIXBUF_FORMAT_WRITABLE) && !(vtable->save || vtable->save_to_callback)) 
 	{
 		error = "loader claims to support saving but doesn't implement save";
 		goto error;
@@ -127,9 +127,9 @@ write_loader_info (const char *path, GdkPixbufFormat *info)
 	char **ext; 
 
 	g_printf("\"%s\"\n", path);
-	g_printf ("\"%s\" %d \"%s\" \"%s\"\n", 
+	g_printf ("\"%s\" %u \"%s\" \"%s\" \"%s\"\n", 
 		  info->name, info->flags, 
-		  info->domain ? info->domain : GETTEXT_PACKAGE, info->description);
+		  info->domain ? info->domain : GETTEXT_PACKAGE, info->description, info->license);
 	for (mime = info->mime_types; *mime; mime++) {
 		g_printf ("\"%s\" ", *mime);
 	}
@@ -208,6 +208,7 @@ query_module (const char *dir, const char *file)
 int main (int argc, char **argv)
 {
 	gint i;
+	gchar *prgname;
 
 #ifdef G_OS_WIN32
 	gchar *libdir;
@@ -254,10 +255,13 @@ int main (int argc, char **argv)
 #define PIXBUF_LIBDIR libdir
 
 #endif
-
+	prgname = g_get_prgname ();
 	g_printf ("# GdkPixbuf Image Loader Modules file\n"
-		"# Automatically generated file, do not edit\n"
-		"#\n");
+		  "# Automatically generated file, do not edit\n"
+		  "# Created by %s from gtk+-%s\n"
+		  "#\n",
+		  (prgname ? prgname : "gdk-pixbuf-query-loaders"),
+		  GDK_PIXBUF_VERSION);
   
 	if (argc == 1) {
 #ifdef USE_GMODULE
