@@ -24,9 +24,7 @@
  * GTK+ at ftp://ftp.gtk.org/pub/gtk/. 
  */
 
-#undef GTK_DISABLE_DEPRECATED
-
-#include <config.h>
+#include "config.h"
 #include <string.h> /* memset */
 
 #include "gtklist.h"
@@ -36,6 +34,7 @@
 #include "gtklabel.h"
 #include "gtkmarshalers.h"
 #include "gtkintl.h"
+
 #include "gtkalias.h"
 
 enum {
@@ -247,7 +246,7 @@ gtk_list_class_init (GtkListClass *class)
   class->unselect_child = gtk_real_list_unselect_child;
 
   list_signals[SELECTION_CHANGED] =
-    gtk_signal_new (I_("selection_changed"),
+    gtk_signal_new (I_("selection-changed"),
 		    GTK_RUN_FIRST,
 		    GTK_CLASS_TYPE (object_class),
 		    GTK_SIGNAL_OFFSET (GtkListClass, selection_changed),
@@ -367,14 +366,10 @@ static void
 gtk_list_size_request (GtkWidget      *widget,
 		       GtkRequisition *requisition)
 {
-  GtkList *list;
+  GtkList *list = GTK_LIST (widget);
   GtkWidget *child;
   GList *children;
 
-  g_return_if_fail (GTK_IS_LIST (widget));
-  g_return_if_fail (requisition != NULL);
-
-  list = GTK_LIST (widget);
   requisition->width = 0;
   requisition->height = 0;
 
@@ -407,16 +402,11 @@ static void
 gtk_list_size_allocate (GtkWidget     *widget,
 			GtkAllocation *allocation)
 {
-  GtkList *list;
+  GtkList *list = GTK_LIST (widget);
   GtkWidget *child;
   GtkAllocation child_allocation;
   GList *children;
 
-  g_return_if_fail (GTK_IS_LIST (widget));
-  g_return_if_fail (allocation != NULL);
-
-  list = GTK_LIST (widget);
-
   widget->allocation = *allocation;
   if (GTK_WIDGET_REALIZED (widget))
     gdk_window_move_resize (widget->window,
@@ -458,8 +448,6 @@ gtk_list_realize (GtkWidget *widget)
   GdkWindowAttr attributes;
   gint attributes_mask;
 
-  g_return_if_fail (GTK_IS_LIST (widget));
-
   GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
 
   attributes.window_type = GDK_WINDOW_CHILD;
@@ -494,15 +482,11 @@ list_has_grab (GtkList *list)
 static void
 gtk_list_unmap (GtkWidget *widget)
 {
-  GtkList *list;
-
-  g_return_if_fail (GTK_IS_LIST (widget));
+  GtkList *list = GTK_LIST (widget);
 
   if (!GTK_WIDGET_MAPPED (widget))
     return;
 
-  list = GTK_LIST (widget);
-
   GTK_WIDGET_UNSET_FLAGS (widget, GTK_MAPPED);
 
   if (list_has_grab (list))
@@ -520,7 +504,7 @@ static gint
 gtk_list_motion_notify (GtkWidget      *widget,
 			GdkEventMotion *event)
 {
-  GtkList *list;
+  GtkList *list = GTK_LIST (widget);
   GtkWidget *item = NULL;
   GtkAdjustment *adj;
   GtkContainer *container;
@@ -531,11 +515,6 @@ gtk_list_motion_notify (GtkWidget      *widget,
   gint focus_row = 0;
   gint length = 0;
 
-  g_return_val_if_fail (GTK_IS_LIST (widget), FALSE);
-  g_return_val_if_fail (event != NULL, FALSE);
-
-  list = GTK_LIST (widget);
-
   if (!list->drag_selection || !list->children)
     return FALSE;
 
@@ -557,7 +536,7 @@ gtk_list_motion_notify (GtkWidget      *widget,
     {
       if (list->htimer == 0)
 	{
-	  list->htimer = g_timeout_add
+	  list->htimer = gdk_threads_add_timeout
 	    (SCROLL_TIME, (GSourceFunc) gtk_list_horizontal_timeout, widget);
 	  
 	  if (!((x < adj->value && adj->value <= 0) ||
@@ -605,7 +584,7 @@ gtk_list_motion_notify (GtkWidget      *widget,
 
   if (!((y < 0 && focus_row == 0) ||
 	(y > widget->allocation.height && focus_row >= length - 1)))
-    list->vtimer = g_timeout_add (SCROLL_TIME,
+    list->vtimer = gdk_threads_add_timeout (SCROLL_TIME,
 				  (GSourceFunc) gtk_list_vertical_timeout,
 				  list);
 
@@ -631,16 +610,12 @@ static gint
 gtk_list_button_press (GtkWidget      *widget,
 		       GdkEventButton *event)
 {
-  GtkList *list;
+  GtkList *list = GTK_LIST (widget);
   GtkWidget *item;
 
-  g_return_val_if_fail (GTK_IS_LIST (widget), FALSE);
-  g_return_val_if_fail (event != NULL, FALSE);
-
   if (event->button != 1)
     return FALSE;
 
-  list = GTK_LIST (widget);
   item = gtk_get_event_widget ((GdkEvent*) event);
 
   while (item && !GTK_IS_LIST_ITEM (item))
@@ -760,14 +735,9 @@ static gint
 gtk_list_button_release (GtkWidget	*widget,
 			 GdkEventButton *event)
 {
-  GtkList *list;
+  GtkList *list = GTK_LIST (widget);
   GtkWidget *item;
 
-  g_return_val_if_fail (GTK_IS_LIST (widget), FALSE);
-  g_return_val_if_fail (event != NULL, FALSE);
-
-  list = GTK_LIST (widget);
-
   /* we don't handle button 2 and 3 */
   if (event->button != 1)
     return FALSE;
@@ -812,8 +782,6 @@ static void
 gtk_list_style_set	(GtkWidget      *widget,
 			 GtkStyle       *previous_style)
 {
-  g_return_if_fail (widget != NULL);
-
   if (previous_style && GTK_WIDGET_REALIZED (widget))
     gdk_window_set_background (widget->window, &widget->style->base[GTK_WIDGET_STATE (widget)]);
 }
@@ -832,7 +800,6 @@ gtk_list_add (GtkContainer *container,
 {
   GList *item_list;
 
-  g_return_if_fail (GTK_IS_LIST (container));
   g_return_if_fail (GTK_IS_LIST_ITEM (widget));
 
   item_list = g_list_alloc ();
@@ -846,9 +813,7 @@ gtk_list_remove (GtkContainer *container,
 		 GtkWidget    *widget)
 {
   GList *item_list;
-  
-  g_return_if_fail (GTK_IS_LIST (container));
-  g_return_if_fail (widget != NULL);
+
   g_return_if_fail (container == GTK_CONTAINER (widget->parent));
   
   item_list = g_list_alloc ();
@@ -865,14 +830,10 @@ gtk_list_forall (GtkContainer  *container,
 		 GtkCallback	callback,
 		 gpointer	callback_data)
 {
-  GtkList *list;
+  GtkList *list = GTK_LIST (container);
   GtkWidget *child;
   GList *children;
 
-  g_return_if_fail (GTK_IS_LIST (container));
-  g_return_if_fail (callback != NULL);
-
-  list = GTK_LIST (container);
   children = list->children;
 
   while (children)
@@ -908,7 +869,7 @@ gtk_list_set_focus_child (GtkContainer *container,
       if (container->focus_child)
 	{
 	  list->last_focus_child = container->focus_child;
-	  gtk_widget_unref (container->focus_child);
+	  g_object_unref (container->focus_child);
 	}
       container->focus_child = child;
       if (container->focus_child)
@@ -1220,7 +1181,7 @@ gtk_list_clear_items (GtkList *list,
       if (widget == list->last_focus_child)
 	list->last_focus_child = NULL;
 
-      gtk_widget_unref (widget);
+      g_object_unref (widget);
     }
 
   g_list_free (start_list);
@@ -1356,7 +1317,7 @@ gtk_list_remove_items_internal (GtkList	 *list,
       if (widget == list->last_focus_child)
 	list->last_focus_child = NULL;
 
-      gtk_widget_unref (widget);
+      g_object_unref (widget);
     }
   
   if (new_focus_child && new_focus_child != old_focus_child)
@@ -2338,26 +2299,18 @@ do_fake_motion (GtkWidget *list)
 static gint
 gtk_list_horizontal_timeout (GtkWidget *list)
 {
-  GDK_THREADS_ENTER ();
-
   GTK_LIST (list)->htimer = 0;
   do_fake_motion (list);
   
-  GDK_THREADS_LEAVE ();
-
   return FALSE;
 }
 
 static gint
 gtk_list_vertical_timeout (GtkWidget *list)
 {
-  GDK_THREADS_ENTER ();
-
   GTK_LIST (list)->vtimer = 0;
   do_fake_motion (list);
 
-  GDK_THREADS_LEAVE ();
-
   return FALSE;
 }
 
@@ -2549,7 +2502,7 @@ gtk_list_signal_item_deselect (GtkListItem *list_item,
     {
       list->selection = g_list_remove_link (list->selection, node);
       g_list_free_1 (node);
-      gtk_widget_unref (GTK_WIDGET (list_item));
+      g_object_unref (list_item);
       gtk_signal_emit (GTK_OBJECT (list), list_signals[SELECTION_CHANGED]);
     }
 }
